Index: branches/rel12/psModules/src/config/pmConfig.h
===================================================================
--- branches/rel12/psModules/src/config/pmConfig.h	(revision 7798)
+++ branches/rel12/psModules/src/config/pmConfig.h	(revision 7876)
@@ -3,6 +3,6 @@
  *  @author PAP, IfA
  *
- *  @version $Revision: 1.11 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-06-28 00:49:13 $
+ *  @version $Revision: 1.11.2.1 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-07-12 21:09:44 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -16,9 +16,10 @@
 // What recipe sources have been read so far?
 typedef enum {
-    P_PM_RECIPE_SOURCE_NONE   = 0x00,   // None yet
-    P_PM_RECIPE_SOURCE_SITE   = 0x01,   // Site configuration
-    P_PM_RECIPE_SOURCE_CAMERA = 0x02,   // Camera configuration
-    P_PM_RECIPE_SOURCE_CL     = 0x04,   // Command-line
-    P_PM_RECIPE_SOURCE_ALL    = 0x07    // All sources
+    P_PM_RECIPE_SOURCE_NONE        = 0x00, // None yet
+    P_PM_RECIPE_SOURCE_SITE        = 0x01, // Site configuration
+    P_PM_RECIPE_SOURCE_CAMERA      = 0x02, // Camera configuration
+    P_PM_RECIPE_SOURCE_CL          = 0x04, // Command-line
+    P_PM_RECIPE_SOURCE_SYMBOLIC    = 0x14, // Symbolic link, specified on command-line
+    P_PM_RECIPE_SOURCE_ALL         = 0xff  // All sources
 } p_pmRecipeSource;
 
@@ -32,5 +33,5 @@
     psMetadata *files;                  // pmFPAfiles used for analysis
     psDB *database;                     // Database handle
-    int argc;                           // Number of command-line arguments
+    int *argc;                          // Number of command-line arguments
     char **argv;                        // Command-line arguments (raw version)
     // Private members
@@ -40,5 +41,5 @@
 pmConfig;
 
-pmConfig *pmConfigAlloc(int argc,       // Number of command-line arguments
+pmConfig *pmConfigAlloc(int *argc,      // Number of command-line arguments
                         char **argv     // Command-line arguments
                        );
@@ -66,5 +67,5 @@
  */
 pmConfig *pmConfigRead(
-    int argc,
+    int *argc,
     char **argv);
 
